@@ -61,7 +61,6 @@ typedef struct {
 #define OVERLAY_DEFAULT_VISUAL_BOOL_OPTION      6
 #define NO_BANDWIDTH_TEST_BOOL_OPTION           7
 #define NO_POWER_CONNECTOR_CHECK_BOOL_OPTION    8
-#define ALLOW_DFP_STEREO_BOOL_OPTION            9
 #define ALLOW_GLX_WITH_COMPOSITE_BOOL_OPTION    10
 #define RANDR_ROTATION_BOOL_OPTION              11
 #define TWINVIEW_BOOL_OPTION                    12
@@ -77,7 +76,6 @@ typedef struct {
 #define MULTISAMPLE_COMPATIBILITY_BOOL_OPTION   22
 #define XVMC_USES_TEXTURES_BOOL_OPTION          23
 #define EXACT_MODE_TIMINGS_DVI_BOOL_OPTION      24
-#define LOAD_KERNEL_MODULE_BOOL_OPTION          26
 #define ADD_ARGB_GLX_VISUALS_BOOL_OPTION        27
 #define COMPOSITE_BOOL_OPTION                   28
 #define DISABLE_GLX_ROOT_CLIPPING_BOOL_OPTION   29
